import { ComponentFixture, TestBed, inject, fakeAsync, tick } from '@angular/core/testing';
import { NgbActiveModal } from '@ng-bootstrap/ng-bootstrap';
import { of } from 'rxjs';
import { EventManager } from 'app/core/util/event-manager.service';

import { GitsearchTestModule } from '../../../test.module';
import { MockEventManager } from '../../../helpers/mock-event-manager.service';
import { MockActiveModal } from '../../../helpers/mock-active-modal.service';
import { UserWatchListDeleteDialogComponent } from 'app/entities/user-watch-list/user-watch-list-delete-dialog.component';
import { UserWatchListService } from 'app/entities/user-watch-list/user-watch-list.service';

describe('Component Tests', () => {
  describe('UserWatchList Management Delete Component', () => {
    let comp: UserWatchListDeleteDialogComponent;
    let fixture: ComponentFixture<UserWatchListDeleteDialogComponent>;
    let service: UserWatchListService;
    let mockEventManager: MockEventManager;
    let mockActiveModal: MockActiveModal;

    beforeEach(() => {
      TestBed.configureTestingModule({
        imports: [GitsearchTestModule],
        declarations: [UserWatchListDeleteDialogComponent],
      })
        .overrideTemplate(UserWatchListDeleteDialogComponent, '')
        .compileComponents();
      fixture = TestBed.createComponent(UserWatchListDeleteDialogComponent);
      comp = fixture.componentInstance;
      service = fixture.debugElement.injector.get(UserWatchListService);
      mockEventManager = TestBed.get(EventManager);
      mockActiveModal = TestBed.get(NgbActiveModal);
    });

    describe('confirmDelete', () => {
      it('Should call delete service on confirmDelete', inject(
        [],
        fakeAsync(() => {
          // GIVEN
          spyOn(service, 'delete').and.returnValue(of({}));

          // WHEN
          comp.confirmDelete(123);
          tick();

          // THEN
          expect(service.delete).toHaveBeenCalledWith(123);
          expect(mockActiveModal.closeSpy).toHaveBeenCalled();
          expect(mockEventManager.broadcastSpy).toHaveBeenCalled();
        })
      ));

      it('Should not call delete service on clear', () => {
        // GIVEN
        spyOn(service, 'delete');

        // WHEN
        comp.cancel();

        // THEN
        expect(service.delete).not.toHaveBeenCalled();
        expect(mockActiveModal.dismissSpy).toHaveBeenCalled();
      });
    });
  });
});
