import { ComponentFixture, TestBed, waitForAsync, fakeAsync, tick} from '@angular/core/testing';
import { GitsearchTestModule } from '../../test.module';
import { TeaserContentComponent } from 'app/teaserContent/teaserContent.component';
import { TranslateModule } from '@ngx-translate/core';
import { SearchService } from 'app/search/service/search-service';
import { MockSearchService } from '../../helpers/mock-search.service';
import { TagCloudModule } from 'angular-tag-cloud-module';
import { RouterTestingModule } from '@angular/router/testing';
import { Router, Routes } from '@angular/router';
import { SearchComponent } from 'app/search/search.component';
import { SearchModule } from 'app/search/search.module';
import { GitSearchV2HomeModule } from 'app/home/home.module';

describe('Component Tests', () => {
  describe('TeaserContent Component', () => {
    let comp: TeaserContentComponent;
    let fixture: ComponentFixture<TeaserContentComponent>;
    let router: Router;

    const routes: Routes = [
      { path: '', redirectTo: 'home', pathMatch: 'full' },
      { path: 'search', component: SearchComponent },
    ];
    beforeEach(
      waitForAsync(() => {
        TestBed.configureTestingModule({
          imports: [
            GitsearchTestModule,
            RouterTestingModule.withRoutes(routes),
            SearchModule,
            GitSearchV2HomeModule,
            TagCloudModule,
            TranslateModule.forRoot(),
          ],
          declarations: [],
          providers: [
            {
              provide: SearchService,
              useClass: MockSearchService,
            },
          ],
        }).compileComponents();
      })
    );

    beforeEach(() => {
      fixture = TestBed.createComponent(TeaserContentComponent);
      comp = fixture.componentInstance;
      router = TestBed.get(Router);
    });

    it('check setup teaser component', fakeAsync(() => {
      // GIVEN

      // WHEN
      comp.ngOnInit();

      tick();
      const navigateSpy = spyOn(router, 'navigate').and.returnValue(null);

      comp.onKeywordClick({ text: 'keyword1' });

      tick();

      expect(navigateSpy).toHaveBeenCalledWith(['/search'], { queryParams: { kw: 'keyword1' } });
      // THEN
    }));
  });
});
